package com.wd.workoffice.presenter;

import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.contract.LoginContract;
import com.wd.workoffice.contract.UserRegisterOneContract;
import com.wd.workoffice.model.LoginModel;

import java.util.Map;

import flexible.xd.android_base.mvpBase.BasePresenter;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import flexible.xd.android_base.network.rtfhttp.observer.BaseObserver;
import io.reactivex.disposables.Disposable;

/**
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class LoginPresenter extends BasePresenter<LoginContract.View, LoginContract.Model>
         implements LoginContract.Presenter {
    @Override
    public void getCode(String phone, String type) {
        mView.showLoading();
        mModel.getCode(phone, type).compose(Transformer.schedule()).subscribe(new BaseObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
                mDisposable.add(d);
            }

            @Override
            public void onFail(String errorMsg) {
                mView.hideLoading();
                mView.onError(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                mView.hideLoading();
                if (data.getCode() != 0) {
                    mView.onError(data.getMessage());
                    return;
                }
                mView.codeSuccess();
            }
        });
    }

    @Override
    public void login(String type, Map<String, Object> param) {
        mView.showLoading();
        mModel.login(type, param).compose(Transformer.schedule()).subscribe(new BaseObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
                mDisposable.add(d);
            }

            @Override
            public void onFail(String errorMsg) {
                mView.hideLoading();
                mView.onError(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                mView.hideLoading();
                if (data.getCode() != 0) {
                    mView.onError(data.getMessage());
                    return;
                }
                mView.loginSuccess();
            }
        });
    }

    @Override
    public LoginContract.Model bindModel() {
        return LoginModel.newInstance();
    }
}
